@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.5.1.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -31,8 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
 
 #ifndef YY_YY_PARSESSH_H_INCLUDED
 # define YY_YY_PARSESSH_H_INCLUDED
@@ -44,46 +45,55 @@
 extern int yydebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    tSTYLE = 258,
-    tIS = 259,
-    tEND = 260,
-    tKEYWORDS = 261,
-    tARE = 262,
-    tIN = 263,
-    tOPERATORS = 264,
-    tSEQUENCES = 265,
-    tFIRST = 266,
-    tSECOND = 267,
-    tALPHABET = 268,
-    tALPHABETS = 269,
-    tDOCUMENTATION = 270,
-    tEXCEPTIONS = 271,
-    tCASE = 272,
-    tCSTRING = 273,
-    tCCHAR = 274,
-    tOPTIONAL = 275,
-    tCLOSERS = 276,
-    tWRITTEN = 277,
-    tBY = 278,
-    tVERSION = 279,
-    tREQUIRES = 280,
-    tA2PS = 281,
-    tANCESTORS = 282,
-    tFACE = 283,
-    tFFLAGS = 284,
-    tSTRING = 285,
-    tLATEXSYMBOL = 286,
-    tREGEX = 287,
-    tSENSITIVENESS = 288,
-    tBACK_REF = 289
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    tSTYLE = 258,                  /* tSTYLE  */
+    tIS = 259,                     /* tIS  */
+    tEND = 260,                    /* tEND  */
+    tKEYWORDS = 261,               /* tKEYWORDS  */
+    tARE = 262,                    /* tARE  */
+    tIN = 263,                     /* tIN  */
+    tOPERATORS = 264,              /* tOPERATORS  */
+    tSEQUENCES = 265,              /* tSEQUENCES  */
+    tFIRST = 266,                  /* tFIRST  */
+    tSECOND = 267,                 /* tSECOND  */
+    tALPHABET = 268,               /* tALPHABET  */
+    tALPHABETS = 269,              /* tALPHABETS  */
+    tDOCUMENTATION = 270,          /* tDOCUMENTATION  */
+    tEXCEPTIONS = 271,             /* tEXCEPTIONS  */
+    tCASE = 272,                   /* tCASE  */
+    tCSTRING = 273,                /* tCSTRING  */
+    tCCHAR = 274,                  /* tCCHAR  */
+    tOPTIONAL = 275,               /* tOPTIONAL  */
+    tCLOSERS = 276,                /* tCLOSERS  */
+    tWRITTEN = 277,                /* tWRITTEN  */
+    tBY = 278,                     /* tBY  */
+    tVERSION = 279,                /* tVERSION  */
+    tREQUIRES = 280,               /* tREQUIRES  */
+    tA2PS = 281,                   /* tA2PS  */
+    tANCESTORS = 282,              /* tANCESTORS  */
+    tFACE = 283,                   /* tFACE  */
+    tFFLAGS = 284,                 /* tFFLAGS  */
+    tSTRING = 285,                 /* tSTRING  */
+    tLATEXSYMBOL = 286,            /* tLATEXSYMBOL  */
+    tREGEX = 287,                  /* tREGEX  */
+    tSENSITIVENESS = 288,          /* tSENSITIVENESS  */
+    tBACK_REF = 289                /* tBACK_REF  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEMPTY -2
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define tSTYLE 258
 #define tIS 259
 #define tEND 260
@@ -121,7 +131,7 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 83 "parsessh.y"
+#line 82 "parsessh.y"
 
   int integer;
   char * string;
@@ -137,7 +147,7 @@ union YYSTYPE
   struct fface_s fface;			/* Flagged face		*/
   enum case_sensitiveness sensitiveness;
 
-#line 141 "parsessh.h"
+#line 151 "parsessh.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -148,6 +158,8 @@ typedef union YYSTYPE YYSTYPE;
 
 extern YYSTYPE yylval;
 
+
 int yyparse (void);
 
+
 #endif /* !YY_YY_PARSESSH_H_INCLUDED  */
